RagAgent class

Inheritance

Constructors

RagAgent({required String? user, required ConnectedChatModel llm, required ChatProvider chatProvider, required VectorSpace vectorSpace})

Properties

chatProvider → ChatProvider
finalinherited
customData Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initialSystemMessage String?
finalinherited
llm → ConnectedChatModel
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user String?
finalinherited
vectorSpace VectorSpace
final

Methods

addMessage(Message message) Future<void>
inherited
call({ToolSchema? responseFormat, List<Tool> tools = const [], int maxRecursiveToolCalls = 1}) Future<AgentMessage>
inherited
getQueryTool() QueryTool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rag({ToolSchema? responseFormat, List<Tool> tools = const [], int maxRecursiveToolCalls = 1}) Future<AgentMessage>
readMessages() Future<List<Message>>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited