PineconeVectorSpace class
- Inheritance
-
- Object
- VectorSpace
- PineconeVectorSpace
Constructors
Properties
- apiKey → String
-
final
- client → PineconeClient
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- namespace → String
-
final
- rerank → bool
-
final
- rerankModel → String
-
final
- rerankTopK → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAll(
List< String> ids, {int batchSize = 999}) → Future<void> -
override
-
deleteAllPrefixed(
String prefix, {int deleteBatchSize = 999, int listBatchSize = 100}) → Future< void> -
inherited
-
list(
{int batchSize = 100, String? prefix}) → Stream< String> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
purgeAll(
) → Future< void> -
override
-
query(
String query, {int maxResults = 10}) → Future< VectorSpaceResult> -
override
-
queryAll(
List< String> queries, {int maxResults = 100, int compactQueriesTo = 10, int maxTokens = 50000}) → Future<VectorSpaceResult> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upsertAll(
List< VectorUpsert> upserts) → Future<void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited